@@ -2,16 +2,15 @@
 This module can load Python modules by path.
 """
 
-from importlib import import_module
-from importlib.machinery import FileFinder
+from importlib.machinery import ModuleSpec
+from importlib.util import module_from_spec, spec_from_file_location
 import inspect
 from logging import Logger
 import logging
 import os
-import pkgutil
 import sys
 from types import ModuleType
-from typing import List, Dict, Tuple
+from typing import List, Dict, Tuple, Optional
 
 from .sample_plugin import SamplePlugin
 
@@ -52,30 +51,21 @@ class _Loader():
 
         # add the parent path to the system PATH if it doesn't already exists
         # this is needed for the import later
-        sys_path_modified: bool = False
-        if os.path.dirname(path) not in sys.path:
-            # insert the parent path at index zero, because the loader should look at this location first
-            sys.path.insert(0, os.path.dirname(path))
-            sys_path_modified = True
+        self.__add_to_pythonpath(path)
 
         # do the actual import
         plugins: Dict[str, type] = self.__load(path,
-                                               os.path.basename(path),  # the module main package is the last directory
-                                                                        # of the path
                                                plugin_base_class,
                                                specific_plugins,
                                                recursive)
 
         # reset the modified path again
-        if (sys_path_modified and
-                os.path.dirname(path) in sys.path):
-            sys.path.remove(os.path.dirname(path))
+        self.__remove_from_pythonpath(path)
 
         self.__available_plugins.update(plugins)
         return plugins
 
     def __load(self, path: str,
-               package_name: str,
                plugin_base_class: type=SamplePlugin,
                specific_plugins: List[str]=[],
                recursive: bool=False) -> Dict[str, type]:
@@ -86,40 +76,61 @@ class _Loader():
         plugins: Dict[str, type] = {}
 
         # use the FileFinder from pkgutil to find the modules
-        importer: FileFinder = FileFinder(path=path)
-        found_modules: List[Tuple[str, bool]] = list(pkgutil.iter_importer_modules(importer))  # type: ignore
 
-        # check if in the current path are only packages
-        only_packages: bool = all([m[1] for m in found_modules])
+        # indicator if in the current path are only directories (will be checked later)
+        only_packages: bool = True
+
+        found_modules: List[Tuple[str, bool]] = []
+        try:
+            dircontents: List[str] = os.listdir(path)
+        except OSError:
+            # ignore unreadable directories like import does
+            dircontents = []
+        for item in dircontents:
+            item = os.path.join(path, item)
+            if os.path.isdir(item):
+                found_modules.append((item, True))
+            elif os.path.isfile(os.path.join(path, item)):
+                module_name: Optional[str] = inspect.getmodulename(item)
+                if module_name and module_name != "__init__":
+                    found_modules.append((item, False))
+                    # now there are not only directories to import
+                    only_packages = False
 
         # iterate over the modules that are within the path
-        for name, ispkg in found_modules:
-            if ispkg:
+        for module_path, is_dir in found_modules:
+            if is_dir:
                 # search in the package if recursive search is requested
                 # or if only packages are found in the path -> try to find plugin modules one level down
                 if recursive or only_packages:
-                    plugins.update(self.__load(os.path.join(path, name),
-                                               ".".join([package_name, name]),
-                                               plugin_base_class,
-                                               specific_plugins,
-                                               recursive))
+                    plugins.update(self.load_plugins(module_path,
+                                                     plugin_base_class,
+                                                     specific_plugins,
+                                                     recursive))
                     continue
                 else:
                     # do not try to import it, since it's not a module
                     continue
 
-            # add the plugin path to PYTHONPATH (needed if the plugin uses imports relative to the plugin module)
-            self.__add_to_pythonpath(path)
-
             # import the module
-            try:
-                imported_module: ModuleType = import_module(".".join([package_name, name]))
-            except ModuleNotFoundError as e:
-                self.log.error("Can't import module '%s'! (%s) -> Skipping it.",
-                               ".".join([package_name, name]), str(e))
+            name: Optional[str] = inspect.getmodulename(module_path)
+            if not name:
+                # this can not happen, because the module name is already checked above
+                # basically the spec_from_file_location method works also with an empty string
+                name = ""
 
-                # remove the path from PYTHONPATH again
-                self.__remove_from_pythonpath(path)
+            try:
+                spec: Optional[ModuleSpec] = spec_from_file_location(name, module_path)
+                if spec:
+                    imported_module: ModuleType = module_from_spec(spec)
+                    if spec.loader:
+                        spec.loader.exec_module(imported_module)
+                    else:
+                        raise ModuleNotFoundError(f"No loader found for module '{name}'")
+                else:
+                    raise ModuleNotFoundError(f"No spec found for module '{name}'")
+            except ModuleNotFoundError as e:
+                self.log.error(f"Can't import module '{name}'! ({e}) -> Skipping it.")
 
                 continue
 
@@ -157,9 +168,6 @@ class _Loader():
             if not plugin_found:
                 del imported_module
 
-                # also remove the path from PYTHONPATH again if the module is not used
-                self.__remove_from_pythonpath(path)
-
         return plugins
 
     def __add_to_pythonpath(self, path: str) -> None:
@@ -169,7 +177,8 @@ class _Loader():
         """
         # only add if it doesn't already exist
         if path not in sys.path:
-            sys.path.append(path)
+            # insert the parent path at index zero, because the loader should look at this location first
+            sys.path.insert(0, path)
 
     def __remove_from_pythonpath(self, path: str) -> None:
         """
